[![Build Status](https://dev.azure.com/robert076kennedy/Tools/_apis/build/status/UniVersion-CI?branchName=develop)](https://dev.azure.com/robert076kennedy/Tools/_build/latest?definitionId=4&branchName=develop) [![PyPI version](https://badge.fury.io/py/universion.svg)](https://badge.fury.io/py/universion) [![Conventional Commits](https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg)](https://conventionalcommits.org)


# universion

An automated versioning tool using [semantic versioning](https://semver.org/) and [conventional commits](https://www.conventionalcommits.org) with the goal of supporting a majority of software project types and languages.
